@@ -165,6 +165,9 @@ class WorkflowEngine:
                 decoded = None
                 try:
                     decoded = base64.b64decode(str_content).decode("ascii", errors='ignore')
+                    if decoded is not None:
+                        if decoded.__contains__("}]"):
+                            decoded = decoded[0:decoded.rfind("}]") + 2]
                 except:
                     str_content = str_content[:-1]
                     str_content = "".join([x for x in str_content if x != '' and x != '']).strip().strip('\x00').strip('\x01').strip('\x0b')
@@ -172,17 +175,20 @@ class WorkflowEngine:
                     try:
                         decoded = base64.b64decode(str_content).decode("ascii", errors='ignore')
                     except:
-                        remain =math.ceil((len(str_content)/4) - int(len(str_content)/4))
+                        remain = math.ceil((len(str_content)/4) - int(len(str_content)/4))
                         str_content = str_content[0:len(str_content)-remain]
                         idx = 0
-                        if str_content.__contains__("fV0"):
+                        if str_content.__contains__("fV0") and not str_content.__contains__("In1d"):
                             str_content = str_content.split("fV0")[0][1:] + "fV0==="
                         if str_content.__contains__("In1d"):
-                            if str_content.index("In1d") + 4 > idx:
+                            if str_content.__contains__("In1d") + 4 > idx:
                                 idx = str_content.index("In1d") + 4
-                        if idx > 0:
+                        while idx > 0 and str_content.__contains__("In1d") and not str_content.endswith("In1d"):
+                            idx = str_content.index("In1d") + 4
                             str_content = str_content[0:idx]
-                decoded = base64.b64decode(str_content).decode("ascii", errors='ignore')
+                        decoded = base64.b64decode(str_content+"==").decode("ascii", errors='ignore')
+                        if decoded.__contains__("}]"):
+                            decoded = decoded[0:decoded.rfind("}]") + 2]
                 dict_list = json.loads(decoded)
                 return dict_list
             else:
@@ -317,6 +323,7 @@ class WorkflowEngine:
                     if ky.lower() == "class":
                         ky = "classname"
                     setattr(tmp, ky, v)
+                self.store_system_variables(tmp)
                 retn.append(tmp)
             # return .flw flow steps
             return retn
@@ -1095,7 +1102,7 @@ class WorkflowEngine:
             if str(getattr(step, value)).__contains__("%__today_formatted__%"):
                 self.variables.update({'%__today_formatted__%': datetime.today().date().strftime("%d-%m-%Y")})
             if str(getattr(step, value)).__contains__("%__month__%"):
-                self.variables.update({'%__month__%': datetime.today().month})
+                self.variables.update({'%__month__%': "{:02d}".format(datetime.today().month)})
             if str(getattr(step, value)).__contains__("%__year__%"):
                 self.variables.update({'%__year__%': datetime.today().year})
             if str(getattr(step, value)).__contains__("%__weeknumber__%"):
@@ -1416,8 +1423,8 @@ class SQL:
             self.run_sql(sql)
             sql = "CREATE TABLE IF NOT EXISTS Steps (id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT, run INTEGER NOT NULL, status TEXT, name TEXT NOT NULL,step TEXT,result TEXT,timestamp DATE DEFAULT (datetime('now','localtime')), CONSTRAINT fk_runs FOREIGN KEY (run) REFERENCES Runs (id) ON DELETE CASCADE);"
             self.run_sql(sql)
-            # sql = "CREATE TABLE IF NOT EXISTS Triggers (id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT, flow_id INTEGER NOT NULL, trigger_info, CONSTRAINT flows_saved_trigger FOREIGN KEY (flow_id) REFERENCES Flows (id) ON DELETE CASCADE);"
-            # self.run_sql(sql)
+            sql = "CREATE TABLE IF NOT EXISTS Survey (id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT, question_id STRING NOT NULL, question STRING NOT NULL, answer_id string NOT NULL, answer STRING NOT NULL, recipient STRING NOT NULL, received INTEGER DEFAULT 0, timestamp DATE DEFAULT (datetime('now','localtime')));"
+            self.run_sql(sql)
         except Exception as ex:
             self.set_error(ex)
             raise Exception(self.error)
@@ -1677,8 +1684,3 @@ class Visio:
         for k, v in properties.items():
             setattr(retn, k, v)
         return retn
-
-engine = WorkflowEngine()
-doc = engine.open("c:\\temp\\test.flw")
-steps = engine.get_flow(doc)
-engine.run_flow(steps)
\ No newline at end of file
